pub struct DeciderConfig {
    pub worker_ipfs_multiaddr: String,
    pub worker_period_sec: u32,
    pub chain_api_endpoint: String,
    pub chain_network_id: u64,
    pub chain_contract_block_hex: String,
    pub chain_matcher_addr: String,
    pub chain_workers_gas: u64,
    pub chain_wallet_key: String,
}
Decider’s configuration needed for the correct decider start-up

Fields

worker_ipfs_multiaddr: String

Multiaddr of the IPFS node from which to take worker definitions

worker_period_sec: u32

How often to run the worker-spell for updates/healthchecks

chain_api_endpoint: String

URI of the RPC for decider to communicate with the chain (poll, send tx)

chain_network_id: u64chain_contract_block_hex: String

The block number from which to poll new deals in hex format

chain_matcher_addr: String

Address of the Matcher contract

chain_workers_gas: u64

How much gas is needed to register a worker

chain_wallet_key: String

Private key to send setWorker tx to chain to register a worker